==> openodia-0.0.9.tar.gz: openodia-0.0.9/openodia/letters.py <==
# -*- coding: utf-8 -*-
"""Letters in Odia language
@author: Soumendra Kumar Sahoo
@date: 19-Sep-2021
"""


class Letters:
    """Letters in Odia language"""

    all_letters = {
        "ଁ",
        "ଂ",
        "ଃ",
        "ଅ",
        "ଆ",
        "ଇ",
        "ଈ",
        "ଉ",
        "ଊ",
        "ଋ",
        "ଌ",
        "ଏ",
        "ଐ",
        "ଓ",
        "ଔ",
        "କ",
        "ଖ",
        "ଗ",
        "ଘ",
        "ଙ",
        "ଚ",
        "ଛ",
        "ଜ",
        "ଝ",
        "ଞ",
        "ଟ",
        "ଠ",
        "ଡ",
        "ଢ",
        "ଣ",
        "ତ",
        "ଥ",
        "ଦ",
        "ଧ",
        "ନ",
        "ପ",
        "ଫ",
        "ବ",
        "ଭ",
        "ମ",
        "ଯ",
        "ର",
        "ଲ",
        "ଳ",
        "ଵ",
        "ଶ",
        "ଷ",
        "ସ",
        "ହ",
        "଼",
        "ଽ",
        "ା",
        "ି",
        "ୀ",
        "ୁ",
        "ୂ",
        "ୃ",
        "ୄ",
        "େ",
        "ୈ",
        "ୋ",
        "ୌ",
        "୍",
        "ୖ",
        "ୗ",
        "ଡ଼",
        "ଢ଼",
        "ୟ",
        "ୠ",
        "ୡ",
        "ୢ",
        "ୣ",
        "୦",
        "୧",
        "୨",
        "୩",
        "୪",
        "୫",
        "୬",
        "୭",
        "୮",
        "୯",
        "୰",
        "ୱ",
        "୲",
    }

    vowels = {"ଅ", "ଆ", "ଇ", "ଈ", "ଉ", "ଊ", "ଋ", "ଌ", "ଏ", "ଐ", "ଓ", "ଔ"}

    numbers = {"୦", "୧", "୨", "୩", "୪", "୫", "୬", "୭", "୮", "୯"}

    consonants = {
        "କ",
        "ଖ",
        "ଗ",
        "ଘ",
        "ଙ",
        "ଚ",
        "ଛ",
        "ଜ",
        "ଝ",
        "ଞ",
        "ଟ",
        "ଠ",
        "ଡ",
        "ଢ",
        "ଣ",
        "ତ",
        "ଥ",
        "ଦ",
        "ଧ",
        "ନ",
        "ପ",
        "ଫ",
        "ବ",
        "ଭ",
        "ମ",
        "ଯ",
        "ର",
        "ଲ",
        "ଳ",
        "ଵ",
        "ଶ",
        "ଷ",
        "ସ",
        "ହ",
    }

    matra = {
        "ଁ",
        "ଂ",
        "ଃ",
        "଼",
        "ଽ",
        "ା",
        "ି",
        "ୀ",
        "ୁ",
        "ୂ",
        "ୃ",
        "ୄ",
        "େ",
        "ୈ",
        "ୋ",
        "ୌ",
        "୍",
        "ୖ",
        "ୗ",
        "୰",
        "ୱ",
        "୲",
    }

==> openodia-0.0.10.tar.gz: openodia-0.0.10/openodia/letters.py <==
# -*- coding: utf-8 -*-
"""Letters in Odia language
@author: Soumendra Kumar Sahoo
@date: 19-Sep-2021
"""


class Letters:
    """Letters in Odia language"""

    all_letters = (
        "ଁ",
        "ଂ",
        "ଃ",
        "ଅ",
        "ଆ",
        "ଇ",
        "ଈ",
        "ଉ",
        "ଊ",
        "ଋ",
        "ଌ",
        "ଏ",
        "ଐ",
        "ଓ",
        "ଔ",
        "କ",
        "ଖ",
        "ଗ",
        "ଘ",
        "ଙ",
        "ଚ",
        "ଛ",
        "ଜ",
        "ଝ",
        "ଞ",
        "ଟ",
        "ଠ",
        "ଡ",
        "ଢ",
        "ଣ",
        "ତ",
        "ଥ",
        "ଦ",
        "ଧ",
        "ନ",
        "ପ",
        "ଫ",
        "ବ",
        "ଭ",
        "ମ",
        "ଯ",
        "ର",
        "ଲ",
        "ଳ",
        "ଵ",
        "ଶ",
        "ଷ",
        "ସ",
        "ହ",
        "଼",
        "ଽ",
        "ା",
        "ି",
        "ୀ",
        "ୁ",
        "ୂ",
        "ୃ",
        "ୄ",
        "େ",
        "ୈ",
        "ୋ",
        "ୌ",
        "୍",
        "ୖ",
        "ୗ",
        "ଡ଼",
        "ଢ଼",
        "ୟ",
        "ୠ",
        "ୡ",
        "ୢ",
        "ୣ",
        "୦",
        "୧",
        "୨",
        "୩",
        "୪",
        "୫",
        "୬",
        "୭",
        "୮",
        "୯",
        "୰",
        "ୱ",
        "୲",
    )

    vowels = ("ଅ", "ଆ", "ଇ", "ଈ", "ଉ", "ଊ", "ଋ", "ଌ", "ଏ", "ଐ", "ଓ", "ଔ")

    numbers = ("୦", "୧", "୨", "୩", "୪", "୫", "୬", "୭", "୮", "୯")

    consonants = (
        "କ",
        "ଖ",
        "ଗ",
        "ଘ",
        "ଙ",
        "ଚ",
        "ଛ",
        "ଜ",
        "ଝ",
        "ଞ",
        "ଟ",
        "ଠ",
        "ଡ",
        "ଢ",
        "ଣ",
        "ତ",
        "ଥ",
        "ଦ",
        "ଧ",
        "ନ",
        "ପ",
        "ଫ",
        "ବ",
        "ଭ",
        "ମ",
        "ଯ",
        "ର",
        "ଲ",
        "ଳ",
        "ଵ",
        "ଶ",
        "ଷ",
        "ସ",
        "ହ",
    )

    matra = (
        "ଁ",
        "ଂ",
        "ଃ",
        "଼",
        "ଽ",
        "ା",
        "ି",
        "ୀ",
        "ୁ",
        "ୂ",
        "ୃ",
        "ୄ",
        "େ",
        "ୈ",
        "ୋ",
        "ୌ",
        "୍",
        "ୖ",
        "ୗ",
        "୰",
        "ୱ",
        "୲",
    )
